@@ -6,7 +6,7 @@ from __future__ import print_function
 from __future__ import unicode_literals
 import tabulate as tabulate_module
 from tabulate import tabulate, simple_separated_format
-from common import assert_equal, assert_raises, SkipTest
+from common import assert_equal, raises, skip
 
 
 # _test_table shows
@@ -59,6 +59,22 @@ def test_plain_multiline():
     assert_equal(expected, result)
 
 
+def test_plain_multiline_with_links():
+    "Output: plain with multiline cells with links and headers"
+    table = [[2, "foo\nbar"]]
+    headers = ("more\nspam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\", "more spam\n& eggs")
+    expected = "\n".join(
+        [
+            "       more  more spam",
+            "  spam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\  & eggs",
+            "          2  foo",
+            "             bar",
+        ]
+    )
+    result = tabulate(table, headers, tablefmt="plain")
+    assert_equal(expected, result)
+
+
 def test_plain_multiline_with_empty_cells():
     "Output: plain with multiline cells and empty cells with headers"
     table = [
@@ -162,6 +178,23 @@ def test_simple_multiline():
     assert_equal(expected, result)
 
 
+def test_simple_multiline_with_links():
+    "Output: simple with multiline cells with links and headers"
+    table = [[2, "foo\nbar"]]
+    headers = ("more\nspam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\", "more spam\n& eggs")
+    expected = "\n".join(
+        [
+            "       more  more spam",
+            "  spam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\  & eggs",
+            "-----------  -----------",
+            "          2  foo",
+            "             bar",
+        ]
+    )
+    result = tabulate(table, headers, tablefmt="simple")
+    assert_equal(expected, result)
+
+
 def test_simple_multiline_with_empty_cells():
     "Output: simple with multiline cells and empty cells with headers"
     table = [
@@ -235,8 +268,7 @@ def test_grid_wide_characters():
     try:
         import wcwidth  # noqa
     except ImportError:
-        print("test_grid_wide_characters is skipped")
-        raise SkipTest()  # this test is optional
+        skip("test_grid_wide_characters is skipped")
     headers = list(_test_table_headers)
     headers[1] = "配列"
     expected = "\n".join(
@@ -767,6 +799,25 @@ def test_pretty_multiline():
     assert_equal(expected, result)
 
 
+def test_pretty_multiline_with_links():
+    "Output: pretty with multiline cells with headers"
+    table = [[2, "foo\nbar"]]
+    headers = ("more\nspam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\", "more spam\n& eggs")
+    expected = "\n".join(
+        [
+            "+-----------+-----------+",
+            "|   more    | more spam |",
+            "| spam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\ |  & eggs   |",
+            "+-----------+-----------+",
+            "|     2     |    foo    |",
+            "|           |    bar    |",
+            "+-----------+-----------+",
+        ]
+    )
+    result = tabulate(table, headers, tablefmt="pretty")
+    assert_equal(expected, result)
+
+
 def test_pretty_multiline_with_empty_cells():
     "Output: pretty with multiline cells and empty cells with headers"
     table = [
@@ -890,6 +941,25 @@ def test_rst_multiline():
     assert_equal(expected, result)
 
 
+def test_rst_multiline_with_links():
+    "Output: rst with multiline cells with headers"
+    table = [[2, "foo\nbar"]]
+    headers = ("more\nspam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\", "more spam\n& eggs")
+    expected = "\n".join(
+        [
+            "===========  ===========",
+            "       more  more spam",
+            "  spam \x1b]8;;target\x1b\\eggs\x1b]8;;\x1b\\  & eggs",
+            "===========  ===========",
+            "          2  foo",
+            "             bar",
+            "===========  ===========",
+        ]
+    )
+    result = tabulate(table, headers, tablefmt="rst")
+    assert_equal(expected, result)
+
+
 def test_rst_multiline_with_empty_cells():
     "Output: rst with multiline cells and empty cells with headers"
     table = [
@@ -1005,7 +1075,11 @@ def test_moinmoin_headerless():
 
 _test_table_html_headers = ["<strings>", "<&numbers&>"]
 _test_table_html = [["spam >", 41.9999], ["eggs &", 451.0]]
-assert_equal.__self__.maxDiff = None
+_test_table_unsafehtml_headers = ["strings", "numbers"]
+_test_table_unsafehtml = [
+    ["spam", '<font color="red">41.9999</font>'],
+    ["eggs", '<font color="red">451.0</font>'],
+]
 
 
 def test_html():
@@ -1029,6 +1103,29 @@ def test_html():
     assert result._repr_html_() == result.str
 
 
+def test_unsafehtml():
+    "Output: unsafe html with headers"
+    expected = "\n".join(
+        [
+            "<table>",
+            "<thead>",
+            "<tr><th>strings  </th><th>numbers                         </th></tr>",  # noqa
+            "</thead>",
+            "<tbody>",
+            '<tr><td>spam     </td><td><font color="red">41.9999</font></td></tr>',
+            '<tr><td>eggs     </td><td><font color="red">451.0</font>  </td></tr>',
+            "</tbody>",
+            "</table>",
+        ]
+    )
+    result = tabulate(
+        _test_table_unsafehtml, _test_table_unsafehtml_headers, tablefmt="unsafehtml"
+    )
+    assert_equal(expected, result)
+    assert hasattr(result, "_repr_html_")
+    assert result._repr_html_() == result.str
+
+
 def test_html_headerless():
     "Output: html without headers"
     expected = "\n".join(
@@ -1047,6 +1144,24 @@ def test_html_headerless():
     assert result._repr_html_() == result.str
 
 
+def test_unsafehtml_headerless():
+    "Output: unsafe html without headers"
+    expected = "\n".join(
+        [
+            "<table>",
+            "<tbody>",
+            '<tr><td>spam</td><td><font color="red">41.9999</font></td></tr>',
+            '<tr><td>eggs</td><td><font color="red">451.0</font>  </td></tr>',
+            "</tbody>",
+            "</table>",
+        ]
+    )
+    result = tabulate(_test_table_unsafehtml, tablefmt="unsafehtml")
+    assert_equal(expected, result)
+    assert hasattr(result, "_repr_html_")
+    assert result._repr_html_() == result.str
+
+
 def test_latex():
     "Output: latex with headers and replaced characters"
     raw_test_table_headers = list(_test_table_headers)
@@ -1310,8 +1425,7 @@ def test_pandas_with_index():
         result = tabulate(df, headers="keys")
         assert_equal(expected, result)
     except ImportError:
-        print("test_pandas_with_index is skipped")
-        raise SkipTest()  # this test is optional
+        skip("test_pandas_with_index is skipped")
 
 
 def test_pandas_without_index():
@@ -1320,7 +1434,9 @@ def test_pandas_without_index():
         import pandas
 
         df = pandas.DataFrame(
-            [["one", 1], ["two", None]], columns=["string", "number"], index=["a", "b"]
+            [["one", 1], ["two", None]],
+            columns=["string", "number"],
+            index=pandas.Index(["a", "b"], name="index"),
         )
         expected = "\n".join(
             [
@@ -1333,8 +1449,7 @@ def test_pandas_without_index():
         result = tabulate(df, headers="keys", showindex=False)
         assert_equal(expected, result)
     except ImportError:
-        print("test_pandas_without_index is skipped")
-        raise SkipTest()  # this test is optional
+        skip("test_pandas_without_index is skipped")
 
 
 def test_pandas_rst_with_index():
@@ -1358,8 +1473,7 @@ def test_pandas_rst_with_index():
         result = tabulate(df, tablefmt="rst", headers="keys")
         assert_equal(expected, result)
     except ImportError:
-        print("test_pandas_rst_with_index is skipped")
-        raise SkipTest()  # this test is optional
+        skip("test_pandas_rst_with_index is skipped")
 
 
 def test_pandas_rst_with_named_index():
@@ -1384,8 +1498,7 @@ def test_pandas_rst_with_named_index():
         result = tabulate(df, tablefmt="rst", headers="keys")
         assert_equal(expected, result)
     except ImportError:
-        print("test_pandas_rst_with_index is skipped")
-        raise SkipTest()  # this test is optional
+        skip("test_pandas_rst_with_index is skipped")
 
 
 def test_dict_like_with_index():
@@ -1418,9 +1531,8 @@ def test_list_of_lists_with_supplied_index():
     assert_equal(result, expected)
     # TODO: make it a separate test case
     # the index must be as long as the number of rows
-    assert_raises(
-        ValueError, lambda: tabulate(dd, headers=["a", "b"], showindex=[1, 2])
-    )
+    with raises(ValueError):
+        tabulate(dd, headers=["a", "b"], showindex=[1, 2])
 
 
 def test_list_of_lists_with_index_firstrow():
@@ -1433,9 +1545,8 @@ def test_list_of_lists_with_index_firstrow():
     assert_equal(result, expected)
     # TODO: make it a separate test case
     # the index must be as long as the number of rows
-    assert_raises(
-        ValueError, lambda: tabulate(dd, headers="firstrow", showindex=[1, 2])
-    )
+    with raises(ValueError):
+        tabulate(dd, headers="firstrow", showindex=[1, 2])
 
 
 def test_disable_numparse_default():
